import Vue from 'vue';

// 1. Import third-party components 导入第三方组件

// echarts
import echarts from 'echarts';
Vue.prototype.$echarts = echarts;

// vue-fab
import VueFab from 'vue-float-action-button/src/index.js';
Vue.use(VueFab, {
  spacing: 70, // 子菜单间距
  delay: 0.1 // 子菜单动画延迟
});

import LoadingPlugin from 'vux/src/plugins/loading/index.js';
import ToastPlugin from 'vux/src/plugins/toast/index.js';
import ConfirmPlugin from 'vux/src/plugins/confirm/index.js';
Vue.use(LoadingPlugin);
Vue.use(ToastPlugin);
Vue.use(ConfirmPlugin);

// 2. Import vue-xmobile, add Dumbo routes and register Dumbo store 

import VueXmobile from 'vue-xmobile';

// store
// Dynamic Module Registration 模块动态注册
const router = VueXmobile.getRouter();
import dumboRoutes from './src/route';
router.addRoutes(dumboRoutes);

// router
const store = VueXmobile.getStore();
import dumboStores from './src/stores';
dumboStores.forEach(s => {
  store.registerModule(s.name, s.store);
});

// languages
import VueI18n from 'vue-i18n';
import messages from './src/langs';

Vue.use(VueI18n);
const i18n = new VueI18n({
  locale: 'cn',
  messages
});

Vue.use(VueXmobile, {
  i18n: (key, value) => i18n.t(key, value),
  i18nMethod: i18n
});

// 设置地图的 Key
store.commit('setBaiduKey', 'ROninBdEIu93CBGDHc3fSPHE');
store.commit('setGaodeKey', '04bdceb300cf826bc9a1dcf0e095246a');

// 设置是否显示微信头
store.commit('UPDATE_NAVBAR_SETTING', { shown: true });
store.commit('setMapType', 'b');

// 3. Import Dumbo

import './src/assets/font/styles.css';
import './src/assets/styles/index.less';
import './src/assets/icons/index.js';
import './src/components/index.js';

export default {
  Vue,
  install: (Vue, options) => { },
  getRouter: () => router,
  getStore: () => store,
  // In theory, the installModule method can only be provided by this project. Other products or projects should use this method for module installation.
  // 理论上 installModule 方法只能由当前项目提供。其他产品或者项目都应该使用该方法进行模块的安装。
  installModule(m) {
    if (m.routes) {
      router.addRoutes(m.routes);
    }

    if (m.stores) {
      m.stores.forEach(s => {
        store.registerModule(s.name, s);
      });
    }
  },
  i18n
};

// 4. Global Settings

// 通知 Android 后台当前页面为非主页面，使用 fireAndroidBackClick 触发返回效果
if (!rt.isWeixin() && rt.isApp()) {
  window.fireAndroidBackClick = function () {
    window.history.go(-1);
  };
}

//操作记录函数（对接数据接口:模块Url,APP主体专供）
window.LogOperateForMenu = function (appurl) {
  try {
    var apiHref = 'api/OperateAnnal/LogOperating?' + 'menuId=' + '&url=' + appurl + '&type=vue' + '&isPc=false';

    rt.post(apiHref, '');
  } catch (e) { }
};

// 修改支持 Android 的返回键
if(window && window.PageState && window.PageState.setPageState) {
  window.PageState.setPageState(1);
}
