export default {
  data() {
    return {
      Id: typeof this.$route.params.id == 'object' ? this.$route.params.id.Id : this.$route.params.id,
      controllerName: '',
      data: {},
      attachmentList: []
    };
  },
  created() {
    this.loadData();
  },
  methods: {
    async loadData() {
      if (!rt.isNilOrWhiteSpace(this.Id)) {
        this.data = await rt.get(`api/${this.controllerName}/GetData?Id=${this.Id}`);
        this.attachmentList = await this.getAttachmentList();
        this.attachmentList.forEach(item => (item.Url = item.downloadUrl));
      }
      if (typeof this.loadComplete === 'function') {
        await this.loadComplete();
      }
    },
    // 验证表单合法性,需要配合rtForm一起使用
    async validate() {
      //验证数据正确性
      if (typeof this.checkFormDataValid === 'function') {
        let errormsgs = await this.checkFormDataValid();
        if (!rt.isNull(errormsgs)) {
          return errormsgs;
        }
      }

      if (!rt.isNull(this.$refs.form)) {
        return await this.$refs.form.validator().then(({ result, errors }) => {
          if (!result) {
            return errors;
          }
        });
      }
    },
    async saveData() {
      try {
        // 执行preSave方法
        if (typeof this.preSave === 'function') {
          var errormsgs = await this.preSave();
          if (!rt.isNilOrWhiteSpace(errormsgs)) {
            rt.showErrorToast(errormsgs);
            return;
          }
        }

        let errors = await this.validate();
        if (!rt.isNull(errors) && errors.length > 0) {
          rt.showErrorToast(errors);
          return;
        }

        const operate = rt.isNilOrWhiteSpace(this.Id) ? 'CreateData' : 'UpdateData';
        const url = `api/${this.controllerName}/${operate}`;
        const id = await rt.post(url, this.data);
        if (rt.isNilOrWhiteSpace(this.Id)) {
          this.Id = id;
        }
        // 执行postSave方法
        if (typeof this.postSave === 'function') {
          await this.postSave();
        }
        rt.showSuccessToast('保存成功');
        this.$bus.$emit('rt-edit-reload');
        this.$router.back();
      } catch (error) {
        rt.showErrorToast(error.message);
      }
    },
    getAttachmentList() {
      const url = `api/${this.controllerName}/GetAttachmentList?id=${this.Id}`;
      return rt.get(url);
    },
    uploadAttachmentList(objectId, attachmentList) {
      return new Promise((resolve, reject) => {
        rt.uploadImageList(objectId, attachmentList, photoList => {
          let promises = photoList.map(item => {
            if (item.LocalId) {
              return this.downloadImage(objectId, item.ServerId);
            }
          });
          Promise.all(promises)
            .then(() => resolve())
            .catch(e => reject(e));
        });
      });
    }
  }
};
